QuoteCache

Struct QuoteCache 

pub struct QuoteCache { /* private fields */ }
Quote cache that accumulates IB tick updates to build complete quotes.

Interactive Brokers sends individual tick price and size updates (bid price, ask price, bid size, ask size). This cache accumulates these updates until we have a complete quote with both bid and ask sides.

Implementations

Source

impl QuoteCache

pub fn new() -> Self

Create a new quote cache.

pub fn update_bid_price( &mut self, instrument_id: InstrumentId, price: f64, price_precision: u8, size_precision: u8, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Option<QuoteTick>

Update bid price and return a complete quote if available.

pub fn update_ask_price( &mut self, instrument_id: InstrumentId, price: f64, price_precision: u8, size_precision: u8, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Option<QuoteTick>

Update ask price and return a complete quote if available.

pub fn update_bid_size( &mut self, instrument_id: InstrumentId, size: f64, price_precision: u8, size_precision: u8, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Option<QuoteTick>

Update bid size and return a complete quote if available.

pub fn update_bid_size_with_filter( &mut self, instrument_id: InstrumentId, size: f64, price_precision: u8, size_precision: u8, ts_event: UnixNanos, ts_init: UnixNanos, ignore_size_only: bool, ) -> Option<QuoteTick>

Update bid size and return a complete quote if available, with optional filtering.

pub fn update_ask_size( &mut self, instrument_id: InstrumentId, size: f64, price_precision: u8, size_precision: u8, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Option<QuoteTick>

Update ask size and return a complete quote if available.

pub fn update_ask_size_with_filter( &mut self, instrument_id: InstrumentId, size: f64, price_precision: u8, size_precision: u8, ts_event: UnixNanos, ts_init: UnixNanos, ignore_size_only: bool, ) -> Option<QuoteTick>

Update ask size and return a complete quote if available, with optional filtering.

pub fn clear(&mut self)

Clear all cached quotes.

pub fn get_last_quote(&self, instrument_id: &InstrumentId) -> Option<&QuoteTick>

Get the last complete quote for an instrument (if available).